==> aws-sdk-cpp-kinesis-1.11.721-1-x86_64.pkg.tar.zst: usr/include/aws/kinesis/model/UpdateShardCountRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/kinesis/KinesisRequest.h>
#include <aws/kinesis/Kinesis_EXPORTS.h>
#include <aws/kinesis/model/ScalingType.h>

#include <utility>

namespace Aws {
namespace Kinesis {
namespace Model {

/**
 */
class UpdateShardCountRequest : public KinesisRequest {
 public:
  AWS_KINESIS_API UpdateShardCountRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "UpdateShardCount"; }

  AWS_KINESIS_API Aws::String SerializePayload() const override;

  AWS_KINESIS_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  /**
   * Helper function to collect parameters (configurable and static hardcoded) required for endpoint computation.
   */
  AWS_KINESIS_API EndpointParameters GetEndpointContextParams() const override;

  ///@{
  /**
   * <p>The name of the stream.</p>
   */
  inline const Aws::String& GetStreamName() const { return m_streamName; }
  inline bool StreamNameHasBeenSet() const { return m_streamNameHasBeenSet; }
  template <typename StreamNameT = Aws::String>
  void SetStreamName(StreamNameT&& value) {
    m_streamNameHasBeenSet = true;
    m_streamName = std::forward<StreamNameT>(value);
  }
  template <typename StreamNameT = Aws::String>
  UpdateShardCountRequest& WithStreamName(StreamNameT&& value) {
    SetStreamName(std::forward<StreamNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The new number of shards. This value has the following default limits. By
   * default, you cannot do the following: </p> <ul> <li> <p>Set this value to more
   * than double your current shard count for a stream.</p> </li> <li> <p>Set this
   * value below half your current shard count for a stream.</p> </li> <li> <p>Set
   * this value to more than 10000 shards in a stream (the default limit for shard
   * count per stream is 10000 per account per region), unless you request a limit
   * increase.</p> </li> <li> <p>Scale a stream with more than 10000 shards down
   * unless you set this value to less than 10000 shards.</p> </li> </ul>
   */
  inline int GetTargetShardCount() const { return m_targetShardCount; }
  inline bool TargetShardCountHasBeenSet() const { return m_targetShardCountHasBeenSet; }
  inline void SetTargetShardCount(int value) {
    m_targetShardCountHasBeenSet = true;
    m_targetShardCount = value;
  }
  inline UpdateShardCountRequest& WithTargetShardCount(int value) {
    SetTargetShardCount(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The scaling type. Uniform scaling creates shards of equal size.</p>
   */
  inline ScalingType GetScalingType() const { return m_scalingType; }
  inline bool ScalingTypeHasBeenSet() const { return m_scalingTypeHasBeenSet; }
  inline void SetScalingType(ScalingType value) {
    m_scalingTypeHasBeenSet = true;
    m_scalingType = value;
  }
  inline UpdateShardCountRequest& WithScalingType(ScalingType value) {
    SetScalingType(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The ARN of the stream.</p>
   */
  inline const Aws::String& GetStreamARN() const { return m_streamARN; }
  inline bool StreamARNHasBeenSet() const { return m_streamARNHasBeenSet; }
  template <typename StreamARNT = Aws::String>
  void SetStreamARN(StreamARNT&& value) {
    m_streamARNHasBeenSet = true;
    m_streamARN = std::forward<StreamARNT>(value);
  }
  template <typename StreamARNT = Aws::String>
  UpdateShardCountRequest& WithStreamARN(StreamARNT&& value) {
    SetStreamARN(std::forward<StreamARNT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_streamName;

  int m_targetShardCount{0};

  ScalingType m_scalingType{ScalingType::NOT_SET};

  Aws::String m_streamARN;
  bool m_streamNameHasBeenSet = false;
  bool m_targetShardCountHasBeenSet = false;
  bool m_scalingTypeHasBeenSet = false;
  bool m_streamARNHasBeenSet = false;
};

}  // namespace Model
}  // namespace Kinesis
}  // namespace Aws

==> aws-sdk-cpp-kinesis-1.11.744-1-x86_64.pkg.tar.zst: usr/include/aws/kinesis/model/UpdateShardCountRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/kinesis/KinesisRequest.h>
#include <aws/kinesis/Kinesis_EXPORTS.h>
#include <aws/kinesis/model/ScalingType.h>

#include <utility>

namespace Aws {
namespace Kinesis {
namespace Model {

/**
 */
class UpdateShardCountRequest : public KinesisRequest {
 public:
  AWS_KINESIS_API UpdateShardCountRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "UpdateShardCount"; }

  AWS_KINESIS_API Aws::String SerializePayload() const override;

  AWS_KINESIS_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  /**
   * Helper function to collect parameters (configurable and static hardcoded) required for endpoint computation.
   */
  AWS_KINESIS_API EndpointParameters GetEndpointContextParams() const override;

  ///@{
  /**
   * <p>The name of the stream.</p>
   */
  inline const Aws::String& GetStreamName() const { return m_streamName; }
  inline bool StreamNameHasBeenSet() const { return m_streamNameHasBeenSet; }
  template <typename StreamNameT = Aws::String>
  void SetStreamName(StreamNameT&& value) {
    m_streamNameHasBeenSet = true;
    m_streamName = std::forward<StreamNameT>(value);
  }
  template <typename StreamNameT = Aws::String>
  UpdateShardCountRequest& WithStreamName(StreamNameT&& value) {
    SetStreamName(std::forward<StreamNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The new number of shards. This value has the following default limits. By
   * default, you cannot do the following: </p> <ul> <li> <p>Set this value to more
   * than double your current shard count for a stream.</p> </li> <li> <p>Set this
   * value below half your current shard count for a stream.</p> </li> <li> <p>Set
   * this value to more than 10000 shards in a stream (the default limit for shard
   * count per stream is 10000 per account per region), unless you request a limit
   * increase.</p> </li> <li> <p>Scale a stream with more than 10000 shards down
   * unless you set this value to less than 10000 shards.</p> </li> </ul>
   */
  inline int GetTargetShardCount() const { return m_targetShardCount; }
  inline bool TargetShardCountHasBeenSet() const { return m_targetShardCountHasBeenSet; }
  inline void SetTargetShardCount(int value) {
    m_targetShardCountHasBeenSet = true;
    m_targetShardCount = value;
  }
  inline UpdateShardCountRequest& WithTargetShardCount(int value) {
    SetTargetShardCount(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The scaling type. Uniform scaling creates shards of equal size.</p>
   */
  inline ScalingType GetScalingType() const { return m_scalingType; }
  inline bool ScalingTypeHasBeenSet() const { return m_scalingTypeHasBeenSet; }
  inline void SetScalingType(ScalingType value) {
    m_scalingTypeHasBeenSet = true;
    m_scalingType = value;
  }
  inline UpdateShardCountRequest& WithScalingType(ScalingType value) {
    SetScalingType(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The ARN of the stream.</p>
   */
  inline const Aws::String& GetStreamARN() const { return m_streamARN; }
  inline bool StreamARNHasBeenSet() const { return m_streamARNHasBeenSet; }
  template <typename StreamARNT = Aws::String>
  void SetStreamARN(StreamARNT&& value) {
    m_streamARNHasBeenSet = true;
    m_streamARN = std::forward<StreamARNT>(value);
  }
  template <typename StreamARNT = Aws::String>
  UpdateShardCountRequest& WithStreamARN(StreamARNT&& value) {
    SetStreamARN(std::forward<StreamARNT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Not Implemented. Reserved for future use.</p>
   */
  inline const Aws::String& GetStreamId() const { return m_streamId; }
  inline bool StreamIdHasBeenSet() const { return m_streamIdHasBeenSet; }
  template <typename StreamIdT = Aws::String>
  void SetStreamId(StreamIdT&& value) {
    m_streamIdHasBeenSet = true;
    m_streamId = std::forward<StreamIdT>(value);
  }
  template <typename StreamIdT = Aws::String>
  UpdateShardCountRequest& WithStreamId(StreamIdT&& value) {
    SetStreamId(std::forward<StreamIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_streamName;

  int m_targetShardCount{0};

  ScalingType m_scalingType{ScalingType::NOT_SET};

  Aws::String m_streamARN;

  Aws::String m_streamId;
  bool m_streamNameHasBeenSet = false;
  bool m_targetShardCountHasBeenSet = false;
  bool m_scalingTypeHasBeenSet = false;
  bool m_streamARNHasBeenSet = false;
  bool m_streamIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace Kinesis
}  // namespace Aws
